@@ -34,7 +34,7 @@ from tinydav.exception import HTTPError, HTTPUserError, HTTPServerError
 
 __author__ = "Manuel Hermann <manuel-hermann@gmx.net>"
 __license__ = "LGPL"
-__version__ = "0.6.6"
+__version__ = "0.6.7"
 
 __all__ = (
     "HTTPError", "HTTPUserError", "HTTPServerError",
@@ -109,14 +109,11 @@ class HTTPResponse(int):
     def _setauth(self):
         value = self.headers.get("www-authenticate", "")
         auth = util.parse_authenticate(value)
-        self.schema = auth.get("schema")
-        self.realm = auth.get("realm")
-        self.domain = auth.get("domain")
-        self.nonce = auth.get("nonce")
-        self.opaque = auth.get("opaque")
+        for attrname in ("schema", "realm", "domain", "nonce", "opaque"):
+            setattr(self, attrname, auth.get(attrname))
         stale = auth.get("stale", "false")
         self.stale = (stale.lower() == "true")
-        algorithm = auth.get("algoritm", "MD5")
+        algorithm = auth.get("algorithm", "MD5")
         self.algorithm = getattr(hashlib, algorithm.lower())
 
 
@@ -1141,6 +1138,7 @@ class CoreWebDAVClient(HTTPClient):
         if depth is not None:
             headers["Depth"] = util.get_depth(depth, ("0", "infinity"))
         content = creator.create_lock(scope, type_, owner)
+        # set a specialized ResponseType as instance var
         self.ResponseType = partial(WebDAVLockResponse, self, uri)
         try:
             lock_response = self._request("LOCK", uri, content, headers)
@@ -1148,7 +1146,8 @@ class CoreWebDAVClient(HTTPClient):
                 self.locks[lock_response._tag] = lock_response
             return lock_response
         finally:
-            self.ResponseType = WebDAVResponse
+            # remove the formerly set ResponseType from the instance
+            del self.ResponseType
 
     def unlock(self, uri_or_lock, locktoken=None, headers=None):
         """Make UNLOCK request and return WebDAVResponse.
